@@ -36,7 +36,7 @@ from . import *
 from . import datalib
 from . import OakProfile_pb2, OakShared_pb2
 
-class BL3ProfItem(object):
+class BL3ProfItem(datalib.BL3Serial):
     """
     Pretty thin wrapper around the serial number for an item.  Mostly
     just so we can keep track of what index it is in the profile.
@@ -45,8 +45,7 @@ class BL3ProfItem(object):
     def __init__(self, serial_number, container, index, datawrapper):
         self.container = container
         self.index = index
-        self.datawrapper = datawrapper
-        self.serial = datalib.BL3Serial(serial_number, datawrapper)
+        super().__init__(serial_number, datawrapper)
 
     @staticmethod
     def create(serial_number, container, datawrapper):
@@ -56,54 +55,13 @@ class BL3ProfItem(object):
         """
         return BL3ProfItem(serial_number, container, -1, datawrapper)
 
-    def get_serial_number(self, orig_seed=False):
+    def _update_superclass_serial(self):
         """
-        Returns the binary item serial number.  If `orig_seed` is `True`, the
-        serial number will use the same seed that was used in the savegame.
-        Otherwise, it will use a seed of `0`, which will then be unencrypted.
+        Action to take when our serial number gets updated.  In this case,
+        overwriting our position in the containing list.
         """
-        return self.serial.get_serial_number(orig_seed)
-
-    def get_serial_base64(self, orig_seed=False):
-        """
-        Returns the base64-encoded item serial number.  If `orig_seed` is
-        `True`, the serial number will use the same seed that was used in the
-        savegame.  Otherwise, it will use a seed of `0`, which will then be
-        unencrypted.
-        """
-        return self.serial.get_serial_base64(orig_seed)
-
-    @property
-    def eng_name(self):
-        """
-        Returns the English name of this item, as best we can tell
-        """
-        return self.serial.eng_name
-
-    @property
-    def balance_short(self):
-        """
-        Returns the 'short' balance name for the item, if possible.  This is
-        generally what'd be useful to a user without being a long full-object
-        name.
-        """
-        return self.serial.balance_short
-
-    @property
-    def level(self):
-        """
-        Returns the level of this item
-        """
-        return self.serial.level
-
-    @level.setter
-    def level(self, new_level):
-        """
-        Sets the level of this item
-        """
-        self.serial.level = new_level
         if self.index >= 0:
-            self.container[self.index] = self.serial.serial
+            self.container[self.index] = self.serial
 
 class BL3Profile(object):
     """
@@ -333,6 +291,25 @@ class BL3Profile(object):
             to_ret[key] = psdu.sdu_level
         return to_ret
 
+    def get_sdus_with_max(self, eng=False):
+        """
+        Returns a dict whose keys are the SDU type, and the values are tuples with
+        two values:
+            1. The number of that SDU type purchased
+            2. The maximum number of SDUs available for that type
+        The SDU type key will be a constant by default, or an English label if
+        `eng` is `True`.  This is just a convenience function suitable for
+        giving more information to users.
+        """
+        to_ret = {}
+        for psdu in self.prof.profile_sdu_list:
+            key = psduobj_to_psdu[psdu.sdu_data_path]
+            max_sdus = psdu_to_max[key]
+            if eng:
+                key = psdu_to_eng[key]
+            to_ret[key] = (psdu.sdu_level, max_sdus)
+        return to_ret
+
     def get_sdu(self, sdu):
         """
         Returns the number of SDUs purchased for the specified type
@@ -404,16 +381,6 @@ class BL3Profile(object):
         else:
             self.prof.bank_inventory_list.append(item_serial)
 
-    def set_bank_item(self, index, item_serial):
-        """
-        Overwrites the `index`th bank item slot with the given `item_serial`, which
-        should either be a `BL3ProfItem` object or a raw-data serial number.
-        """
-        if type(item_serial) == BL3ProfItem:
-            self.prof.bank_inventory_list[index] = item_serial.get_serial_number()
-        else:
-            self.prof.bank_inventory_list[index] = item_serial
-
     def get_cur_customizations(self, cust_set):
         """
         Returns a set of the currently-unlocked customizations which live in the
