@@ -25,33 +25,9 @@ import os
 import sys
 import bl3save
 import argparse
-from . import datalib
+from . import cli_common
 from bl3save.bl3profile import BL3Profile
 
-class DictAction(argparse.Action):
-    """
-    Custom argparse action to put list-like arguments into
-    a dict (where the value will be True) rather than a list.
-    This is probably implemented fairly shoddily.
-    """
-    def __init__(self, option_strings, dest, nargs=None, **kwargs):
-        """
-        Constructor, taken right from https://docs.python.org/2.7/library/argparse.html#action
-        """
-        if nargs is not None:
-            raise ValueError('nargs is not allowed')
-        super(DictAction, self).__init__(option_strings, dest, **kwargs)
-
-    def __call__(self, parser, namespace, values, option_string=None):
-        """
-        Actually setting a value.  Forces the attr into a dict if it isn't already.
-        """
-        arg_value = getattr(namespace, self.dest)
-        if not isinstance(arg_value, dict):
-            arg_value = {}
-        arg_value[values] = True
-        setattr(namespace, self.dest, arg_value)
-
 def main():
 
     # Set up args
@@ -105,6 +81,19 @@ def main():
             type=int,
             help='Set all bank items to the specified level')
 
+    itemmayhemgroup = parser.add_mutually_exclusive_group()
+
+    itemmayhemgroup.add_argument('--item-mayhem-max',
+            dest='item_mayhem_max',
+            action='store_true',
+            help='Set all bank items to the maximum Mayhem level ({})'.format(bl3save.mayhem_max))
+
+    itemmayhemgroup.add_argument('--item-mayhem-levels',
+            dest='item_mayhem_levels',
+            type=int,
+            choices=range(bl3save.mayhem_max+1),
+            help='Set all bank items to the specified Mayhem level (0 to remove)')
+
     parser.add_argument('-i', '--import-items',
             dest='import_items',
             type=str,
@@ -137,7 +126,7 @@ def main():
             'customizations',
             ]
     parser.add_argument('--unlock',
-            action=DictAction,
+            action=cli_common.DictAction,
             choices=unlock_choices + ['all'],
             default={},
             help='Game features to unlock',
@@ -171,6 +160,10 @@ def main():
     if args.item_levels_max:
         args.item_levels = bl3save.max_level
 
+    # Set max mayhem arg
+    if args.item_mayhem_max:
+        args.item_mayhem_levels = bl3save.mayhem_max
+
     # Check item level.  The max storeable in the serial number is 127, but the
     # effective limit in-game is 100, thanks to MaxGameStage attributes.  We
     # could use `bl3save.max_level` here, too, of course, but in the event that
@@ -204,6 +197,7 @@ def main():
         args.item_levels,
         args.clear_customizations,
         args.alpha,
+        args.item_mayhem_levels is not None,
         ])
 
     # Make changes
@@ -285,72 +279,28 @@ def main():
 
         # Import Items
         if args.import_items:
-            if not args.quiet:
-                print(' - Importing items from {}'.format(args.import_items))
-            added_count = 0
-            with open(args.import_items) as df:
-                for line in df:
-                    itemline = line.strip()
-                    if itemline.lower().startswith('bl3(') and itemline.endswith(')'):
-                        new_item = profile.create_new_item_encoded(itemline)
-                        if not args.allow_fabricator:
-                            # Report these regardless of args.quiet
-                            if not new_item.eng_name:
-                                print('   - NOTICE: Skipping unknown item import because --allow-fabricator is not set')
-                                continue
-                            if new_item.balance_short.lower() == 'balance_eridian_fabricator':
-                                print('   - NOTICE: Skipping Fabricator import because --allow-fabricator is not set')
-                                continue
-                        profile.add_bank_item(new_item)
-                        if not args.quiet:
-                            if new_item.eng_name:
-                                print('   + {} (level {})'.format(new_item.eng_name, new_item.level))
-                            else:
-                                print('   + unknown item')
-                        added_count += 1
-            if not args.quiet:
-                print('   - Added Item Count: {}'.format(added_count))
+            cli_common.import_items(args.import_items,
+                    profile.create_new_item_encoded,
+                    profile.add_bank_item,
+                    allow_fabricator=args.allow_fabricator,
+                    quiet=args.quiet,
+                    )
 
         # Setting item levels.  Keep in mind that we'll want to do this *after*
         # various of the actions above.  If we've been asked to change the level
         # of items, we'll want to do it after the item import.
         if args.item_levels:
-            num_items = len(profile.get_bank_items())
-            if not args.quiet:
-                if num_items == 1:
-                    plural = ''
-                else:
-                    plural = 's'
-                print(' - Updating {} item{} to level {}'.format(
-                    num_items,
-                    plural,
+            cli_common.update_item_levels(profile.get_bank_items(),
                     args.item_levels,
-                    ))
-            actually_updated = 0
-            for idx, item in enumerate(profile.get_bank_items()):
-                if item.level != args.item_levels:
-                    item.level = args.item_levels
-                    profile.set_bank_item(idx, item)
-                    actually_updated += 1
-            if not args.quiet:
-                remaining = num_items - actually_updated
-                if actually_updated == 1:
-                    updated_verb = 'was'
-                else:
-                    updated_verb = 'were'
-                if remaining > 0:
-                    if remaining == 1:
-                        remaining_verb = 'was'
-                    else:
-                        remaining_verb = 'were'
-                    remaining_txt = ' ({} {} already at that level)'.format(remaining, remaining_verb)
-                else:
-                    remaining_txt = ''
-                print('   - {} {} updated{}'.format(
-                    actually_updated,
-                    updated_verb,
-                    remaining_txt,
-                    ))
+                    quiet=args.quiet,
+                    )
+
+        # Item Mayhem level
+        if args.item_mayhem_levels is not None:
+            cli_common.update_item_mayhem_levels(profile.get_bank_items(),
+                    args.item_mayhem_levels,
+                    quiet=args.quiet,
+                    )
 
         # Newline at the end of all this.
         if not args.quiet:
@@ -370,16 +320,11 @@ def main():
         if not args.quiet:
             print('Wrote JSON to {}'.format(args.output_filename))
     elif args.output == 'items':
-        with open(args.output_filename, 'w') as df:
-            for item in profile.get_bank_items():
-                if item.eng_name:
-                    print('# {} (level {})'.format(item.eng_name, item.level), file=df)
-                else:
-                    print('# unknown item', file=df)
-                print(item.get_serial_base64(), file=df)
-                print('', file=df)
-        if not args.quiet:
-            print('Wrote {} items (in base64 format) to {}'.format(len(profile.get_bank_items()), args.output_filename))
+        cli_common.export_items(
+                profile.get_bank_items(),
+                args.output_filename,
+                quiet=args.quiet,
+                )
     else:
         # Not sure how we'd ever get here
         raise Exception('Invalid output format specified: {}'.format(args.output))
